ms3 - Parsing MuseScore 3 — ms3 0.1.2.post0.dev2+g9d887e1.dirty documentation

# ms3 - Parsing MuseScore 3

Welcome to ms3, a Python library for parsing annotated MuseScore 3 files. It

- parses uncompressed MuseScore 3 files (`*.mscx`),

- stores the contained information in a tabular format (`*.tsv`),

- deletes and writes annotation labels to MuseScores <Harmony> layer,

- parses and transforms labels following the DCML harmonic annotation standard

## Contents

- Installation
  - Unix-based systems
    - Using Python >= 3.6
    - Installing via `pip`
- Quick Reference
  - Parsing a single score
- Manual
  - Parsing a single score
    - Parsing options
- License
- Authors
- Changelog
  - Version 0.2.0
  - Version 0.1.3
  - Version 0.1.0

## Indices and tables

- Index

- Module Index

- Search Page